package jugs.javafx.b_properties;

import javafx.application.Application;
import javafx.beans.binding.Bindings;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.geometry.Insets;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.ListView;
import javafx.scene.control.Separator;
import javafx.scene.control.TextField;
import javafx.scene.control.ToolBar;
import javafx.scene.layout.VBox;
import javafx.stage.Stage;

/**
 * Beispielprogramm für JavaFX-Schulung 
 * 
 * @author Michael Inden
 * 
 * Copyright 2015 by Michael Inden 
 */
public class Exercise1_ListViewModificationExample extends Application
{
    @Override
    public void start(final Stage primaryStage)
    {
        final String[] names = { "Micha", "Andi", "Andy", "Tom", "Matze" };
        final ObservableList<String> entries = FXCollections.observableArrayList(names);

        final ListView<String> listView = new ListView<>(entries);

        final Button addButton = new Button("Add");
        final TextField textfield = new TextField();
        final Button removeButton = new Button("Remove");
        final ToolBar toolbar = new ToolBar(addButton, textfield, new Separator(), removeButton);

        final VBox vBox = new VBox();
        vBox.setPadding(new Insets(5, 5, 5, 5));
        vBox.getChildren().addAll(toolbar, listView);

        // Action-Handling
        addButton.setOnAction(event -> entries.add(textfield.getText()));
        removeButton.setOnAction(event -> {
            final String selected = listView.getSelectionModel().getSelectedItem();
            if (selected != null)
            {
                entries.remove(selected);
            }
        });

        // Button Disabling
        addButton.disableProperty().bind(textfield.textProperty().isEmpty());
        removeButton.disableProperty()
                        .bind(Bindings.size(listView.getSelectionModel().getSelectedItems()).isEqualTo(0));

        primaryStage.setScene(new Scene(vBox, 350, 250));
        primaryStage.setTitle("ListViewModificationExample");
        primaryStage.show();
    }

    public static void main(String[] args)
    {
        Application.launch(args);
    }
}