package jugs.javafx.b_properties;

import javafx.application.Application;
import javafx.beans.value.ChangeListener;
import javafx.beans.value.ObservableValue;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.geometry.Insets;
import javafx.scene.Scene;
import javafx.scene.control.ListView;
import javafx.scene.control.TextField;
import javafx.scene.layout.VBox;
import javafx.stage.Stage;

/**
 * Beispielprogramm für JavaFX-Schulung 
 * 
 * @author Michael Inden
 * 
 * Copyright 2015 by Michael Inden 
 */
public class Exercise3_FilterListExample_JDK7 extends Application
{
    private static final String[]        names   = { "Kai", "Micha", "Andi", "Andy", "Tom", "Matze", "Mike", "Florian" };

    private final ObservableList<String> entries = FXCollections.observableArrayList(names);

    @Override
    public void start(Stage primaryStage)
    {
        primaryStage.setTitle(this.getClass().getSimpleName());
        final ListView<String> listView = new ListView<>(entries);
        listView.setPrefHeight(150);

        final TextField searchFor = new TextField();
        searchFor.textProperty().addListener(new ChangeListener<String>()
        {
            @Override
            public void changed(ObservableValue<? extends String> observable, String oldValue, String newValue)
            {
                if (oldValue != null && (newValue.length() < oldValue.length()))
                {
                    listView.setItems(entries);
                }

                listView.setItems(containsFilter(entries, newValue));
            }
        });
        final VBox vBox = new VBox();
        vBox.setPadding(new Insets(5, 5, 5, 5));
        vBox.setSpacing(10);
        vBox.getChildren().addAll(searchFor, listView);
        primaryStage.setScene(new Scene(vBox, 300, 250));
        primaryStage.show();
    }

    public ObservableList<String> containsFilter(final ObservableList<String> originalContent, final String value)
    {
        final ObservableList<String> subentries = FXCollections.observableArrayList();

        final String filterValue = value.toUpperCase();
        for (final String entry : originalContent)
        {
            if (entry.toUpperCase().contains(filterValue))
            {
                subentries.add(entry);
            }
        }

        return subentries;
    }

    public static void main(String[] args)
    {
        launch(args);
    }
}